package javax.net.ssl;

import java.net.InetAddress;
import java.io.IOException;
import java.net.ServerSocket;

public abstract class SSLServerSocket extends ServerSocket
{
    protected SSLServerSocket() throws IOException {
    }
    
    protected SSLServerSocket(int port) throws IOException {
        super(port);
    }
    
    protected SSLServerSocket(int port, int backlog) throws IOException {
        super(port, backlog);
    }
    
    protected SSLServerSocket(int port, int backlog, InetAddress bindAddr) throws IOException {
        super(port, backlog, bindAddr);
    }
    
    public abstract String[] getEnabledCipherSuites();
    
    public abstract void setEnabledCipherSuites(String[] p0);
    
    public abstract String[] getSupportedCipherSuites();
    
    public abstract String[] getSupportedProtocols();
    
    public abstract String[] getEnabledProtocols();
    
    public abstract void setEnabledProtocols(String[] p0);
    
    public abstract void setNeedClientAuth(boolean p0);
    
    public abstract boolean getNeedClientAuth();
    
    public abstract void setWantClientAuth(boolean p0);
    
    public abstract boolean getWantClientAuth();
    
    public abstract void setUseClientMode(boolean p0);
    
    public abstract boolean getUseClientMode();
    
    public abstract void setEnableSessionCreation(boolean p0);
    
    public abstract boolean getEnableSessionCreation();
    
    public SSLParameters getSSLParameters() {
        SSLParameters sslParameters = new SSLParameters();
        sslParameters.setCipherSuites(this.getEnabledCipherSuites());
        sslParameters.setProtocols(this.getEnabledProtocols());
        if (this.getNeedClientAuth()) {
            sslParameters.setNeedClientAuth(true);
        }
        else if (this.getWantClientAuth()) {
            sslParameters.setWantClientAuth(true);
        }
        return sslParameters;
    }
    
    public void setSSLParameters(SSLParameters sslParameters) {
        String[] cipherSuites = sslParameters.getCipherSuites();
        if (cipherSuites != null) {
            this.setEnabledCipherSuites(cipherSuites);
        }
        String[] protocols = sslParameters.getProtocols();
        if (protocols != null) {
            this.setEnabledProtocols(protocols);
        }
        if (sslParameters.getNeedClientAuth()) {
            this.setNeedClientAuth(true);
        }
        else if (sslParameters.getWantClientAuth()) {
            this.setWantClientAuth(true);
        }
        else {
            this.setWantClientAuth(false);
        }
    }
}
